# FundingSummaryV30Rc2

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_date** | [**CreatedDateV30Rc2**](CreatedDateV30Rc2.md) |  | [optional] 
**last_modified_date** | [**LastModifiedDateV30Rc2**](LastModifiedDateV30Rc2.md) |  | [optional] 
**source** | [**SourceV30Rc2**](SourceV30Rc2.md) |  | [optional] 
**title** | [**FundingTitleV30Rc2**](FundingTitleV30Rc2.md) |  | 
**external_ids** | [**ExternalIDsV30Rc2**](ExternalIDsV30Rc2.md) |  | [optional] 
**url** | [**UrlV30Rc2**](UrlV30Rc2.md) |  | [optional] 
**type** | **str** |  | 
**start_date** | [**FuzzyDateV30Rc2**](FuzzyDateV30Rc2.md) |  | [optional] 
**end_date** | [**FuzzyDateV30Rc2**](FuzzyDateV30Rc2.md) |  | [optional] 
**organization** | [**OrganizationV30Rc2**](OrganizationV30Rc2.md) |  | 
**visibility** | **str** |  | [optional] 
**put_code** | **int** |  | [optional] 
**path** | **str** |  | [optional] 
**display_index** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

